==> openGion7.0.0.0_dev.zip: uap/webapps/ge/db/ORACLE/sql/install/01_TABLE/GEA06S.sql <==
/****************************************************************************/
/* GEA06 ( ﾃﾞｰﾀﾛｰﾙﾏｽﾀ )                                                     */
/*                                                                          */
/* Created : 2018/09/28 16:03:20                                            */
/****************************************************************************/

CREATE TABLE GEA06 (
   SYSTEM_ID    VARCHAR2 (  10 )                    NOT NULL            /*  10 ｼｽﾃﾑID   */
 , DROLE        VARCHAR2 (  20 )                    NOT NULL            /*  20 ﾃﾞｰﾀﾛｰﾙ  */
 , CLM          VARCHAR2 (  30 )                    NOT NULL            /*  30 項目     */
 , CVALUE       VARCHAR2 ( 200 )                    NOT NULL            /*  40 値       */
 , VALCDTN      VARCHAR2 (  10 )                    NOT NULL            /*  50 条件     */
 , UNIQ         NUMBER   (   9 )        DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ          VARCHAR2 (   1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        VARCHAR2 (  14 )                                        /* 820 登録日時 */
 , PGSET        VARCHAR2 (  10 )                                        /* 830 作成PG   */
 , PGPSET       VARCHAR2 (  10 )                                        /* 840 作成親PG */
 , USRSET       VARCHAR2 (  10 )                                        /* 850 作成者   */
 , DYUPD        VARCHAR2 (  14 )                                        /* 860 更新日時 */
 , PGUPD        VARCHAR2 (  10 )                                        /* 870 更新PG   */
 , PGPUPD       VARCHAR2 (  10 )                                        /* 880 更新親PG */
 , USRUPD       VARCHAR2 (  10 )                                        /* 890 更新者   */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K );


CREATE SEQUENCE GEA06S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;


CREATE OR REPLACE TRIGGER GEA06T00 
  BEFORE INSERT ON GEA06
  FOR EACH ROW 
  BEGIN 
    SELECT GEA06S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/

==> openGion7.4.0.0_dev.zip: uap/webapps/ge/db/ORACLE/sql/install/01_TABLE/GEA06S.sql <==
/****************************************************************************/
/* GEA06 ( ﾃﾞｰﾀﾛｰﾙﾏｽﾀ )                                                     */
/*                                                                          */
/* Created : 2020/12/16 08:13:51                                            */
/****************************************************************************/

CREATE TABLE GEA06 (
   SYSTEM_ID    VARCHAR2 (  10 )                    NOT NULL            /*  10 ｼｽﾃﾑID   */
 , DROLE        VARCHAR2 (  20 )                    NOT NULL            /*  20 ﾃﾞｰﾀﾛｰﾙ  */
 , CLM          VARCHAR2 (  30 )                    NOT NULL            /*  30 項目     */
 , CVALUE       VARCHAR2 ( 200 )                    NOT NULL            /*  40 値       */
 , VALCDTN      VARCHAR2 (  10 )                    NOT NULL            /*  50 条件     */
 , UNIQ         NUMBER   (   9 )        DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ          VARCHAR2 (   1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        VARCHAR2 (  14 )                                        /* 820 作成日時 */
 , PGSET        VARCHAR2 (  10 )                                        /* 830 作成PG   */
 , PGPSET       VARCHAR2 (  10 )                                        /* 840 作成親PG */
 , USRSET       VARCHAR2 (  10 )                                        /* 850 作成者   */
 , DYUPD        VARCHAR2 (  14 )                                        /* 860 更新日時 */
 , PGUPD        VARCHAR2 (  10 )                                        /* 870 更新PG   */
 , PGPUPD       VARCHAR2 (  10 )                                        /* 880 更新親PG */
 , USRUPD       VARCHAR2 (  10 )                                        /* 890 更新者   */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K );


CREATE SEQUENCE GEA06S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;


CREATE OR REPLACE TRIGGER GEA06T00 
  BEFORE INSERT ON GEA06
  FOR EACH ROW 
  BEGIN 
    SELECT GEA06S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/
